@@ -15,11 +15,13 @@
 #' @param limit integer limit of query results (1000 by default)
 #' @param article_model_group integer articleModel parameter query
 #' @param article_model integer articleModel parameter query
+#' @param return_raw boolean Return raw data from json structure as a tibble data.frame
 #'
 #' @return A data frame. Returns NULL if no connection.
 #'
 #' @importFrom httr2 req_headers req_url_path_append req_url_query req_retry req_perform resp_body_json
 #' @importFrom dplyr filter pull as_tibble left_join select
+#' @importFrom purrr pmap_dfr
 #' @importFrom curl has_internet
 #'
 #' @seealso \code{\link{bfs_get_data}}
@@ -27,9 +29,13 @@
 #' \describe{
 #'   \item{title}{A character column with the title of the BFS dataset}
 #'   \item{language}{A character column with the language of the BFS dataset}
-#'   \item{publication_date}{The published date of the BFS dataset in the data catalog}
 #'   \item{number_asset}{The BFS asset number}
+#'   \item{number_bfs}{The BFS number (FSO number), named orderNr in the API}
+#'   \item{publication_date}{The published date of the BFS dataset, named embargo in the API}
+#'   \item{language_available}{A list The list of all languages available for the BFS dataset}
 #'   \item{url_px}{A character column with the URL of the PX file}
+#'   \item{url_structure_json}{A character column with the URL of the json structure of the BFS dataset}
+#'   \item{damId}{DAM API unique ID}
 #' }
 #'
 #' @examples
@@ -41,7 +47,7 @@
 #' dplyr packages). Returns NULL if no connection.
 #'
 #' @export
-bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search = NULL, spatial_division = NULL, prodima = NULL, inquiry = NULL, institution = NULL, publishing_year_start = NULL, publishing_year_end = NULL, order_nr = NULL, limit = 1000, article_model = 900033, article_model_group = 900029) {
+bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search = NULL, spatial_division = NULL, prodima = NULL, inquiry = NULL, institution = NULL, publishing_year_start = NULL, publishing_year_end = NULL, order_nr = NULL, limit = 1000, article_model = 900033, article_model_group = 900029, return_raw = FALSE) {
   # fail gracefully if no internet connection
   if (!curl::has_internet()) {
     message("No internet connection")
@@ -86,28 +92,30 @@ bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search
   
   df <- as_tibble(df_raw$data)
   
+  if(return_raw == TRUE) {
+    return(df)
+  }
+  
   if(nrow(df) == 0) {
     df_final <- dplyr::tibble(
       title = NA_character_,
       language = NA_character_,
-      publication_date = as.Date(x = integer(0)),
+      number_bfs = NA_character_,
       number_asset = NA_character_,
-      order_nr = NA_character_,
+      publication_date = as.Date(x = integer(0)),
       url_px = NA_character_,
-      language_available = list(),
-      url_structure_json = NA_character_
+      url_structure_json = NA_character_,
+      damId = integer(0)
     )
     return(df_final)
   }
   
-  language_available <- strsplit(tolower(df$description$language), split = "/")
-  
+
   df_catalog_metadata <- dplyr::tibble(
     title = df$description$titles$main,
     language = language,
+    number_bfs = df$shop$orderNr,
     publication_date = as.Date(df$bfs$embargo),
-    order_nr = df$shop$orderNr,
-    language_available = language_available,
     damId = df$ids$damId
   )
   
@@ -136,16 +144,11 @@ bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search
       filter(rel == "related") %>%
       pull(href)
     
-    url_structure_json <- df_links %>%
-      filter(rel == "related-further") %>%
-      pull(href)
-    
     number_asset <- basename(url_asset)
 
     df_links_cleaned <- dplyr::tibble(
       number_asset = number_asset[1],
       url_px = url_px[1],
-      url_structure_json = url_structure_json[1],
       damId = damId
     )
     return(df_links_cleaned)
@@ -158,7 +161,7 @@ bfs_get_catalog_data <- function(language = "de", title = NULL, extended_search
   
   df_final <- df_catalog_metadata |>
     left_join(df_catalog_links_metadata, by = "damId") |>
-    select(title, language, number_asset, publication_date, order_nr, url_px, language_available, url_structure_json, damId)
+    select(title, language, number_bfs, number_asset, publication_date, url_px)
   
   return(df_final)
 }
