@@ -15,6 +15,7 @@
 #' @param limit integer limit of query results (1000 by default)
 #' @param article_model_group integer articleModel parameter query
 #' @param article_model integer articleModel parameter query
+#' @param return_raw boolean Return raw data from json structure as a tibble data.frame
 #'
 #' @return A data frame. Returns NULL if no connection.
 #'
@@ -40,7 +41,7 @@
 #' dplyr packages). Returns NULL if no connection.
 #'
 #' @export
-bfs_get_catalog_tables <- function(language = "de", title = NULL, extended_search = NULL, spatial_division = NULL, prodima = NULL, inquiry = NULL, institution = NULL, publishing_year_start = NULL, publishing_year_end = NULL, order_nr = NULL, limit = 1000, article_model = 900030, article_model_group = 900029) {
+bfs_get_catalog_tables <- function(language = "de", title = NULL, extended_search = NULL, spatial_division = NULL, prodima = NULL, inquiry = NULL, institution = NULL, publishing_year_start = NULL, publishing_year_end = NULL, order_nr = NULL, limit = 1000, article_model = 900030, article_model_group = 900029, return_raw = FALSE) {
   # fail gracefully if no internet connection
   if (!curl::has_internet()) {
     message("No internet connection")
@@ -85,26 +86,26 @@ bfs_get_catalog_tables <- function(language = "de", title = NULL, extended_searc
   
   df <- as_tibble(df_raw$data)
   
+  if(return_raw == TRUE) {
+    return(df)
+  }
+  
   if(nrow(df) == 0) {
     df_final <- dplyr::tibble(
       title = NA_character_,
       language = NA_character_,
       publication_date = as.Date(x = integer(0)),
       number_asset = NA_character_,
-      order_nr = NA_character_,
-      language_available = list()
+      order_nr = NA_character_
     )
     return(df_final)
   }
   
-  language_available <- strsplit(tolower(df$description$language), split = "/")
-  
   df_catalog_metadata <- dplyr::tibble(
     title = df$description$titles$main,
     language = language,
     publication_date = as.Date(df$bfs$embargo),
     order_nr = df$shop$orderNr,
-    language_available = language_available,
     damId = df$ids$damId
   )
   
@@ -143,7 +144,7 @@ bfs_get_catalog_tables <- function(language = "de", title = NULL, extended_searc
   
   df_final <- df_catalog_metadata |>
     left_join(df_catalog_links_metadata, by = "damId") |>
-    select(title, language, number_asset, publication_date, order_nr, language_available, damId)
+    select(title, language, number_asset, publication_date, order_nr)
   
   return(df_final)
 }
